==> vokoscreen_2.4.0.orig.tar.gz: vokoscreen-2.4.0/language/vokoscreen_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Spedisci via mail l&apos;ultimo video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Spedisci via mail uno o più video selezionati</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Troverete il video come allegato</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selezionare uno o più file</translation>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bordi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User-defined</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Used by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>doubleclick extended to the edge</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>schermo intero</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>finestre</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>area</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Lente di ingrandimento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Non registrare il cursore del mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Ubicazione del video</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Riproduttore</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizza Vokoscreen quando inizia la registrazione</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata della registrazione</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Dimensioni in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Dimensioni dello schermo da registrare</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Impostazioni fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Conto alla rovescia</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Riproduci ultimo video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Invia video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Selezionare una o più periferiche</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogrammi al secondo attuale</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>inizio</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagina iniziale</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistenza</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Sviluppatore</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Fotogrammi</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donate</translation>
    </message>
    <message>
        <source>Program for recording</source>
        <translation>Programma per registrare</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra nella systray</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleziona webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All Displays</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> vokoscreen_2.5.0.orig.tar.gz: vokoscreen-2.5.0/language/vokoscreen_it_IT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>AlsaBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usato da</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <source>Show Click Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MailDialog</name>
    <message>
        <source>Mail last Video</source>
        <translation>Spedisci via mail l&apos;ultimo video</translation>
    </message>
    <message>
        <source>Mail one or more selected Video</source>
        <translation>Spedisci via mail uno o più video selezionati</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>NoPlayerDialog</name>
    <message>
        <source>Please install a videoplayer</source>
        <translation>Installa un lettore multimediale</translation>
    </message>
</context>
<context>
    <name>QvkMail</name>
    <message>
        <source>You find the Video as attachment</source>
        <translation>Il video è in allegato</translation>
    </message>
    <message>
        <source>Select one or more files</source>
        <translation>Selezionare uno o più file</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QvkWebcamWindow</name>
    <message>
        <source>Border</source>
        <translation>Bordi</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Show over fullscreen</source>
        <translation>Mostra su schermo intero</translation>
    </message>
    <message>
        <source>Right click for menu</source>
        <translation>Clic destro per il menù</translation>
    </message>
    <message>
        <source>User-defined</source>
        <translation>Definito dall&apos;utente</translation>
    </message>
</context>
<context>
    <name>WebcamBusyDialog</name>
    <message>
        <source>Device is busy</source>
        <translation>La periferica è occupata</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Dispositivo</translation>
    </message>
    <message>
        <source>Used by</source>
        <translation>Usato da</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Sconosciuto</translation>
    </message>
</context>
<context>
    <name>regionselection</name>
    <message>
        <source>double-click to maximize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>screencast</name>
    <message>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Finestra</translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Area</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Ingrandimento</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Alsa</source>
        <translation>Alsa</translation>
    </message>
    <message>
        <source>Pulse</source>
        <translation>Pulse</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>Codec</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Non registrare il cursore del mouse</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Salva in</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Riproduci con</translation>
    </message>
    <message>
        <source>Vokoscreen minimized when recording starts</source>
        <translation>Minimizza Vokoscreen quando inizia la registrazione</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Riproduci</translation>
    </message>
    <message>
        <source>Send</source>
        <translation>Invia</translation>
    </message>
    <message>
        <source>Recording time</source>
        <translation>Durata della registrazione</translation>
    </message>
    <message>
        <source>Size in KB</source>
        <translation>Dimensione in KB</translation>
    </message>
    <message>
        <source>Recording screensize</source>
        <translation>Dimensioni dello schermo da registrare</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <source>Settings fps</source>
        <translation>Impostazione fps</translation>
    </message>
    <message>
        <source>Open Directory</source>
        <translation>Apri cartella</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Ritarda avvio</translation>
    </message>
    <message>
        <source>Play last Video</source>
        <translation>Riproduci ultimo video</translation>
    </message>
    <message>
        <source>Send Video</source>
        <translation>Invia video</translation>
    </message>
    <message>
        <source>Select one or more devices</source>
        <translation>Seleziona una o più periferiche</translation>
    </message>
    <message>
        <source>Actual frames per second</source>
        <translation>Fotogrammi al secondo reali</translation>
    </message>
    <message>
        <source>Go</source>
        <translation>Avvia</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Pagina iniziale</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Assistenza</translation>
    </message>
    <message>
        <source>Developer</source>
        <translation>Sviluppatore</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Fai una donazione</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Traduzioni</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Codice sorgente</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Mostra nella systray</translation>
    </message>
    <message>
        <source>New version available</source>
        <translation>Nuova versione disponibile</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Select webcam</source>
        <translation>Seleziona webcam</translation>
    </message>
    <message>
        <source>Mirrored</source>
        <translation>Specchiato</translation>
    </message>
    <message>
        <source>Display</source>
        <translation>Schermo</translation>
    </message>
    <message>
        <source>All Displays</source>
        <translation>Tutti gli schermi</translation>
    </message>
    <message>
        <source>Developer Homepage</source>
        <translation>Pagina dello sviluppatore</translation>
    </message>
    <message>
        <source>Recorder</source>
        <translation>Recorder</translation>
    </message>
    <message>
        <source>Select recorder</source>
        <translation>Selezionare un recorder</translation>
    </message>
    <message>
        <source>Hide window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lossless</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
